==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fa.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "شناسهٔ ابری خودگردان نامعتبر",
    "Server to server sharing is not enabled on this server" : "هم‌رسانی کارساز به کارساز روی این کارساز به کار نیفتاده",
    "Couldn't establish a federated share." : "نمی توان یک سهم فدرال ایجاد کرد.",
    "Couldn't establish a federated share, maybe the password was wrong." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، شاید رمز عبور اشتباه بوده است.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "درخواست اشتراک فدرال ارسال شد، یک دعوت نامه دریافت خواهید کرد. اعلان های خود را بررسی کنید.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، به نظر می‌رسد سروری که باید با آن فدرال شود خیلی قدیمی است (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "ارسال اشتراک های گروه فدرال از این سرور مجاز نیست.",
    "Federated shares require read permissions" : "سهام فدرال به مجوز خواندن نیاز دارد",
    "File is already shared with %s" : "فایل قبلاً با به اشتراک گذاشته شده است%s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "اشتراک‌گذاری %1$s انجام نشد، پیدا نشد%2$s، شاید سرور در حال حاضر غیرقابل دسترسی باشد یا از گواهی امضا شده استفاده می‌کند.",
    "Could not find share" : "نتوانست هم‌رسانی را بیابد",
    "Federated sharing" : "هم‌رسانی خودگردان",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "شما {share} را به عنوان یک اشتراک راه دور از {user} دریافت کردید (از طرف {behalf})",
    "You received {share} as a remote share from {user}" : "شما {share} را به عنوان اشتراک راه دور از {user} دریافت کردید",
    "Accept" : "قبول",
    "Decline" : "کاهش می یابد",
    "Federated Cloud Sharing" : "هم‌رسانی ابری خودگردان",
    "Sharing" : "هم‌رسانی",
    "Federated file sharing" : "هم‌رسانی پروندهٔ خودگردان",
    "Provide federated file sharing across servers" : "فراهم‌کنندهٔ هم‌رسانی پروندهٔ خودگردان میان کارسازها",
    "Unable to update federated files sharing config" : "به‌روزرسانی پیکربندی اشتراک‌گذاری فایل‌های فدرال ممکن نیست",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید، به {url} مراجعه کنید",
    "Share with me through my #Nextcloud Federated Cloud ID" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید",
    "Cloud ID copied to the clipboard" : "Cloud ID در کلیپ بورد کپی شد",
    "Copy to clipboard" : "رونوشت به تخته‌گیره",
    "Copied!" : "رونوشت شد!",
    "Federated Cloud" : "ابر خودگردان",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "می‌توانید با هر کسی که از سرور Nextcloud یا سایر سرورها و سرویس‌های سازگار با Open Cloud Mesh (OCM) استفاده می‌کند، اشتراک‌گذاری کنید! فقط شناسه ابری فدرال آنها را در گفتگوی اشتراک گذاری قرار دهید. به نظر می رسد person@cloud.example.com",
    "Share it so your friends can share files with you:" : "آن را به اشتراک بگذارید تا دوستانتان بتوانند فایل ها را با شما به اشتراک بگذارند:",
    "Facebook" : "فیس‌بوک",
    "Mastodon" : "Mastodon",
    "Add to your website" : "افزودن به پایگاه وبتان",
    "Share with me via Nextcloud" : "هم‌رسانی با من روی نسکت‌کلود",
    "HTML Code:" : "کد HTML :",
    "Cancel" : "لغو",
    "Add remote share" : "افزودن هم‌رسانی دوردست",
    "Remote share" : "هم‌رسانی دوردست",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "می‌خواهید هم‌رسانی دوردست {name} را از ‪{owner}@{remote}‬ بیفزایید؟",
    "Remote share password" : "گذرواژهٔ هم‌رسانی دوردست",
    "Clipboard is not available" : "کلیپ بورد در دسترس نیست",
    "Your Federated Cloud ID:" : "شناسهٔ ابردی خودگردانتان:",
    "Twitter" : "توییتر",
    "Diaspora" : "دیازپورا"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fa.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "شناسهٔ ابری خودگردان نامعتبر",
    "Server to server sharing is not enabled on this server" : "هم‌رسانی کارساز به کارساز روی این کارساز به کار نیفتاده",
    "Couldn't establish a federated share." : "نمی توان یک سهم فدرال ایجاد کرد.",
    "Couldn't establish a federated share, maybe the password was wrong." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، شاید رمز عبور اشتباه بوده است.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "درخواست اشتراک فدرال ارسال شد، یک دعوت نامه دریافت خواهید کرد. اعلان های خود را بررسی کنید.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "نمی‌توان یک اشتراک فدرال ایجاد کرد، به نظر می‌رسد سروری که باید با آن فدرال شود خیلی قدیمی است (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "ارسال اشتراک های گروه فدرال از این سرور مجاز نیست.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "اشتراک‌گذاری %1$s ناموفق بود، زیرا این مورد قبلاً با حساب %2$s به اشتراک گذاشته شده است",
    "Federated shares require read permissions" : "سهام فدرال به مجوز خواندن نیاز دارد",
    "File is already shared with %s" : "فایل قبلاً با به اشتراک گذاشته شده است%s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "اشتراک‌گذاری %1$s انجام نشد، پیدا نشد%2$s، شاید سرور در حال حاضر غیرقابل دسترسی باشد یا از گواهی امضا شده استفاده می‌کند.",
    "Could not find share" : "نتوانست هم‌رسانی را بیابد",
    "Federated sharing" : "هم‌رسانی خودگردان",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "شما {share} را به عنوان یک اشتراک راه دور از {user} دریافت کردید (از طرف {behalf})",
    "You received {share} as a remote share from {user}" : "شما {share} را به عنوان اشتراک راه دور از {user} دریافت کردید",
    "Accept" : "قبول",
    "Decline" : "کاهش می یابد",
    "Federated Cloud Sharing" : "هم‌رسانی ابری خودگردان",
    "Sharing" : "هم‌رسانی",
    "Federated file sharing" : "هم‌رسانی پروندهٔ خودگردان",
    "Provide federated file sharing across servers" : "فراهم‌کنندهٔ هم‌رسانی پروندهٔ خودگردان میان کارسازها",
    "Unable to update federated files sharing config" : "به‌روزرسانی پیکربندی اشتراک‌گذاری فایل‌های فدرال ممکن نیست",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید، به {url} مراجعه کنید",
    "Share with me through my #Nextcloud Federated Cloud ID" : "از طریق شناسه ابری فدرال #Nextcloud با من به اشتراک بگذارید",
    "Share with me via Nextcloud" : "هم‌رسانی با من روی نسکت‌کلود",
    "Copy" : "کپی",
    "Copied!" : "رونوشت شد!",
    "Federated Cloud" : "ابر خودگردان",
    "Share it so your friends can share files with you:" : "آن را به اشتراک بگذارید تا دوستانتان بتوانند فایل ها را با شما به اشتراک بگذارند:",
    "Facebook" : "فیس‌بوک",
    "Mastodon" : "Mastodon",
    "Add to your website" : "افزودن به پایگاه وبتان",
    "HTML Code:" : "کد HTML :",
    "Cancel" : "لغو",
    "Add remote share" : "افزودن هم‌رسانی دوردست",
    "Remote share" : "هم‌رسانی دوردست",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "می‌خواهید هم‌رسانی دوردست {name} را از ‪{owner}@{remote}‬ بیفزایید؟",
    "Remote share password" : "گذرواژهٔ هم‌رسانی دوردست",
    "Cloud ID copied to the clipboard" : "Cloud ID در کلیپ بورد کپی شد",
    "Copy to clipboard" : "رونوشت به تخته‌گیره",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "می‌توانید با هر کسی که از سرور Nextcloud یا سایر سرورها و سرویس‌های سازگار با Open Cloud Mesh (OCM) استفاده می‌کند، اشتراک‌گذاری کنید! فقط شناسه ابری فدرال آنها را در گفتگوی اشتراک گذاری قرار دهید. به نظر می رسد person@cloud.example.com"
},
"nplurals=2; plural=(n > 1);");
